@@ -10,20 +10,23 @@ __all__ = (
     "AdjustmentRejectedError",
     "BaseError",
     "ConnectorError",
+    "ConnectorNotFoundError",
     "EventAbortedError",
     "EventCancelledError",
+    "EventHandlersNotFoundError",
     "EventError",
     "MeasurementFailedError",
     "ServoError",
     "UnexpectedEventError",
 )
 
+
 class BaseError(RuntimeError):
     """The base class for all errors in the servo package."""
 
     def __init__(
         self,
-        message: str = '',
+        message: str = "",
         reason: Optional[str] = None,
         *args,
         assembly: Optional[servo.Assembly] = None,
@@ -35,6 +38,7 @@ class BaseError(RuntimeError):
 
         # Use the context vars to infer the assembly, servo, connector, and event
         import servo
+
         self._reason = reason
         self._assembly = assembly or servo.current_assembly()
         self._servo = servo_ or servo.current_servo()
@@ -76,38 +80,56 @@ class BaseError(RuntimeError):
         """The event that was executing when the error occurred."""
         return self._event
 
+
 class ServoError(BaseError):
     """An error occurred within a servo."""
+
     @property
     def servo(self) -> servo.Servo:
         return self._servo
 
+
+class ConnectorNotFoundError(ServoError):
+    """A mission critical attempt to locate a connector by name or ID has failed"""
+
+
 class ConnectorError(ServoError):
     """An error occurred within a connector."""
+
     @property
-    def connector(self) -> servo.Connector:
+    def connector(self) -> servo.connector.BaseConnector:
         return self._connector
 
+
+class EventHandlersNotFoundError(ConnectorError):
+    """None of the currently assembled connectors implement handlers for the Event being checked"""
+
+
 class EventError(ConnectorError):
     """An error occurred during the processing of an event by a connector."""
+
     @property
     def event(self) -> servo.Event:
         return self._event
 
+
 class UnexpectedEventError(EventError):
     """The optimizer reported that an unexpected error was submitted."""
 
+
 class EventCancelledError(EventError):
     """The event was cancelled and processing was halted."""
 
+
 class MeasurementFailedError(EventError):
-    """A failure occurred while attempting to perform an measurement.
+    """A failure occurred while attempting to perform a measurement.
 
     Measurement failures are potentially recoverable errors in which the
     measurement was not fully collected due to a transient failure, lost
     connection, interruption, etc. and be retried by the optimizer.
     """
 
+
 class AdjustmentFailedError(EventError):
     """A failure occurred while attempting to perform an adjustment.
 
@@ -116,6 +138,7 @@ class AdjustmentFailedError(EventError):
     connection, interruption, etc. and be retried by the optimizer.
     """
 
+
 class AdjustmentRejectedError(AdjustmentFailedError):
     """The adjustment was irrecoverably rejected when applied.
 
@@ -125,9 +148,10 @@ class AdjustmentRejectedError(AdjustmentFailedError):
     applied configuration from further consideration by the optimizer.
     """
 
+
 class EventAbortedError(EventError):
     """Abort the currently running event
 
-    During long running measurements (and, optionally, adjustments) it is often
-    neccessary to complete the operation early eg. if there are sustained SLO violations.
+    During long-running measurements (and, optionally, adjustments) it is often
+    necessary to complete the operation early e.g. if there are sustained SLO violations.
     """
