@@ -5,8 +5,9 @@ import asyncio
 import contextlib
 import contextvars
 import enum
+import functools
 import json
-from typing import Any, Dict, List, Optional, Protocol, Sequence, Tuple, Union
+from typing import Any, Optional, Protocol, Sequence, Tuple, Union
 
 import httpx
 import pydantic
@@ -21,11 +22,12 @@ import servo.types
 import servo.utilities
 import servo.utilities.pydantic
 
-__all__ = ['Servo', 'Events', 'current_servo']
+__all__ = ["Servo", "Events", "current_servo"]
 
 
 _current_context_var = contextvars.ContextVar("servox.current_servo", default=None)
 
+
 def current_servo() -> Optional["Servo"]:
     """Return the active servo for the current execution context.
 
@@ -33,6 +35,7 @@ def current_servo() -> Optional["Servo"]:
     """
     return _current_context_var.get(None)
 
+
 def _set_current_servo(servo_: Optional["Servo"]) -> None:
     """Set the active servo for the current execution context.
 
@@ -87,11 +90,11 @@ class _EventDefinitions(Protocol):
 
     # Informational events
     @servo.events.event(Events.metrics)
-    async def metrics(self) -> List[servo.types.Metric]:
+    async def metrics(self) -> list[servo.types.Metric]:
         ...
 
     @servo.events.event(Events.components)
-    async def components(self) -> List[servo.types.Component]:
+    async def components(self) -> list[servo.types.Component]:
         ...
 
     # Operational events
@@ -99,7 +102,7 @@ class _EventDefinitions(Protocol):
     async def measure(
         self,
         *,
-        metrics: List[str] = None,
+        metrics: list[str] = None,
         control: servo.types.Control = servo.types.Control(),
     ) -> servo.types.Measurement:
         if control.delay:
@@ -113,17 +116,19 @@ class _EventDefinitions(Protocol):
         halt_on: Optional[
             servo.types.ErrorSeverity
         ] = servo.types.ErrorSeverity.critical,
-    ) -> List[servo.checks.Check]:
+    ) -> list[servo.checks.Check]:
         ...
 
     @servo.events.event(Events.describe)
-    async def describe(self, control: servo.types.Control = servo.types.Control()) -> servo.types.Description:
+    async def describe(
+        self, control: servo.types.Control = servo.types.Control()
+    ) -> servo.types.Description:
         ...
 
     @servo.events.event(Events.adjust)
     async def adjust(
         self,
-        adjustments: List[servo.types.Adjustment],
+        adjustments: list[servo.types.Adjustment],
         control: servo.types.Control = servo.types.Control(),
     ) -> servo.types.Description:
         ...
@@ -188,34 +193,35 @@ class Servo(servo.connector.BaseConnector):
     connector.
     """
 
-    connectors: List[servo.connector.BaseConnector]
+    connectors: list[servo.connector.BaseConnector]
     """The active connectors in the Servo.
     """
 
     _running: bool = pydantic.PrivateAttr(False)
 
-    async def dispatch_event(self, *args, **kwargs) -> Union[Optional[servo.events.EventResult], List[servo.events.EventResult]]:
+    async def dispatch_event(
+        self, *args, **kwargs
+    ) -> Union[Optional[servo.events.EventResult], list[servo.events.EventResult]]:
         with self.current():
             return await super().dispatch_event(*args, **kwargs)
 
     def __init__(
-        self, *args, connectors: List[servo.connector.BaseConnector], **kwargs
-    ) -> None: # noqa: D107
+        self, *args, connectors: list[servo.connector.BaseConnector], **kwargs
+    ) -> None:  # noqa: D107
         super().__init__(*args, connectors=[], **kwargs)
 
         # Ensure the connectors refer to the same objects by identity (required for eventing)
         self.connectors.extend(connectors)
 
         # associate shared config with our children
-        for connector in (connectors + [self]):
+        for connector in connectors + [self]:
             connector._global_config = self.config.settings
 
     @pydantic.root_validator()
-    def _initialize_name(cls, values: Dict[str, Any]) -> Dict[str, Any]:
-        if values["name"] == "servo" and values.get('config'):
-            values["name"] = (
-                values["config"].name
-                or getattr(values["config"].optimizer, 'id', 'servo')
+    def _initialize_name(cls, values: dict[str, Any]) -> dict[str, Any]:
+        if values["name"] == "servo" and values.get("config"):
+            values["name"] = values["config"].name or getattr(
+                values["config"].optimizer, "id", "servo"
             )
 
         return values
@@ -233,20 +239,22 @@ class Servo(servo.connector.BaseConnector):
         """Return True if the servo is running."""
         return self._running
 
-    async def startup(self):
+    async def startup(self) -> None:
         """Notify all active connectors that the servo is starting up."""
         if self.is_running:
             raise RuntimeError("Cannot start up a servo that is already running")
 
         self._running = True
 
-        await self.dispatch_event(Events.startup, _prepositions=servo.events.Preposition.on)
+        await self.dispatch_event(
+            Events.startup, _prepositions=servo.events.Preposition.on
+        )
 
         # Start up the pub/sub exchange
         if not self.pubsub_exchange.running:
             self.pubsub_exchange.start()
 
-    async def shutdown(self):
+    async def shutdown(self) -> None:
         """Notify all active connectors that the servo is shutting down."""
         if not self.is_running:
             raise RuntimeError("Cannot shut down a servo that is not running")
@@ -261,13 +269,20 @@ class Servo(servo.connector.BaseConnector):
         self._running = False
 
     @property
-    def all_connectors(self) -> List[servo.connector.BaseConnector]:
+    def all_connectors(self) -> list[servo.connector.BaseConnector]:
         """Return a list of all active connectors including the Servo."""
         return [self, *self.connectors]
 
+    def connectors_named(self, names: Sequence[str]) -> list[servo.BaseConnector]:
+        return [
+            connector for connector in self.all_connectors if connector.name in names
+        ]
+
     def get_connector(
         self, name: Union[str, Sequence[str]]
-    ) -> Optional[Union[servo.connector.BaseConnector, List[servo.connector.BaseConnector]]]:
+    ) -> Optional[
+        Union[servo.connector.BaseConnector, list[servo.connector.BaseConnector]]
+    ]:
         """Return one or more connectors by name.
 
         This is a convenience method equivalent to iterating `connectors` and comparing by name.
@@ -276,16 +291,9 @@ class Servo(servo.connector.BaseConnector):
         When given a sequence of names, returns a list of Connectors for all connectors found.
         """
         if isinstance(name, str):
-            for connector in self.connectors:
-                if connector.name == name:
-                    return connector
-            return None
+            return next(iter(self.connectors_named([name])), None)
         else:
-            connectors = []
-            for connector in self.connectors:
-                if connector.name == name:
-                    connectors.append(connector)
-            return connectors
+            return self.connectors_named(name)
 
     async def add_connector(
         self, name: str, connector: servo.connector.BaseConnector
@@ -327,7 +335,9 @@ class Servo(servo.connector.BaseConnector):
         # Start the connector if we are running
         if self.is_running:
             await self.dispatch_event(
-                Events.startup, include=[connector], _prepositions=servo.events.Preposition.on
+                Events.startup,
+                include=[connector],
+                _prepositions=servo.events.Preposition.on,
             )
 
     async def remove_connector(
@@ -359,7 +369,9 @@ class Servo(servo.connector.BaseConnector):
         # Shut the connector down if we are running
         if self.is_running:
             await self.dispatch_event(
-                Events.shutdown, include=[connector_], _prepositions=servo.events.Preposition.on
+                Events.shutdown,
+                include=[connector_],
+                _prepositions=servo.events.Preposition.on,
             )
 
         await self.dispatch_event(Events.detach, self, include=[connector])
@@ -376,7 +388,7 @@ class Servo(servo.connector.BaseConnector):
         with servo.utilities.pydantic.extra(self.config):
             delattr(self.config, connector_.name)
 
-    def top_level_schema(self, *, all: bool = False) -> Dict[str, Any]:
+    def top_level_schema(self, *, all: bool = False) -> dict[str, Any]:
         """Return a schema that only includes connector model definitions"""
         connectors = servo.Assembly.all_connector_types() if all else self.connectors
         config_models = list(map(lambda c: c.config_model(), connectors))
@@ -390,6 +402,101 @@ class Servo(servo.connector.BaseConnector):
             default=pydantic.json.pydantic_encoder,
         )
 
+    async def check_servo(self, print_callback: Callable[[str], None] = None) -> bool:
+
+        connectors = self.config.checks.connectors
+        name = self.config.checks.name
+        id = self.config.checks.id
+        tag = self.config.checks.tag
+
+        quiet = self.config.checks.quiet
+        progressive = self.config.checks.progressive
+        wait = self.config.checks.wait
+        delay = self.config.checks.delay
+        halt_on = self.config.checks.halt_on
+
+        # Validate that explicit args support check events
+        connector_objs = (
+            self.connectors_named(connectors)
+            if connectors
+            else list(
+                filter(
+                    lambda c: c.responds_to_event(servo.Events.check),
+                    self.all_connectors,
+                )
+            )
+        )
+        if not connector_objs:
+            if connectors:
+                raise servo.ConnectorNotFoundError(
+                    f"no connector found with name(s) '{connectors}'"
+                )
+            else:
+                raise servo.EventHandlersNotFoundError(
+                    f"no currently assembled connectors respond to the check event"
+                )
+        validate_connectors_respond_to_event(connector_objs, servo.Events.check)
+
+        if wait:
+            summary = "Running checks"
+            summary += " progressively" if progressive else ""
+            summary += f" for up to {wait} with a delay of {delay} between iterations"
+            servo.logger.info(summary)
+
+        passing = set()
+        progress = servo.DurationProgress(servo.Duration(wait or 0))
+        ready = False
+
+        while not progress.finished:
+            if not progress.started:
+                # run at least one time
+                progress.start()
+
+            args = dict(
+                name=servo.utilities.parse_re(name),
+                id=servo.utilities.parse_id(id),
+                tags=servo.utilities.parse_csv(tag),
+            )
+            constraints = dict(filter(lambda i: bool(i[1]), args.items()))
+
+            results: List[servo.EventResult] = (
+                await self.dispatch_event(
+                    servo.Events.check,
+                    servo.CheckFilter(**constraints),
+                    include=self.all_connectors,
+                    halt_on=halt_on,
+                )
+                or []
+            )
+
+            ready = await servo.checks.CheckHelpers.process_checks(
+                checks_config=self.config.checks,
+                results=results,
+                passing=passing,
+            )
+            if not progressive and not quiet:
+                output = await servo.checks.CheckHelpers.checks_to_table(
+                    checks_config=self.config.checks, results=results
+                )
+                print_callback(output)
+
+            if ready:
+                return ready
+            else:
+                if wait and delay is not None:
+                    servo.logger.info(
+                        f"waiting for {delay} before rerunning failing checks"
+                    )
+                    await asyncio.sleep(servo.Duration(delay).total_seconds())
+
+                if progress.finished:
+                    # Don't log a timeout if we aren't running in wait mode
+                    if progress.duration:
+                        servo.logger.error(
+                            f"timed out waiting for checks to pass {progress.duration}"
+                        )
+                    return ready
+
     ##
     # Event handlers
 
@@ -397,8 +504,10 @@ class Servo(servo.connector.BaseConnector):
     async def check(
         self,
         matching: Optional[servo.checks.CheckFilter],
-        halt_on: Optional[servo.types.ErrorSeverity] = servo.types.ErrorSeverity.critical,
-    ) -> List[servo.checks.Check]:
+        halt_on: Optional[
+            servo.types.ErrorSeverity
+        ] = servo.types.ErrorSeverity.critical,
+    ) -> list[servo.checks.Check]:
         """Check that the servo is ready to perform optimization.
 
         Args:
@@ -433,8 +542,18 @@ class Servo(servo.connector.BaseConnector):
     def current(self):
         """A context manager that sets the current servo context."""
         try:
-          token = _current_context_var.set(self)
-          yield self
+            token = _current_context_var.set(self)
+            yield self
 
         finally:
             _current_context_var.reset(token)
+
+
+def validate_connectors_respond_to_event(
+    connectors: Iterable[servo.BaseConnector], event: str
+) -> None:
+    for connector in connectors:
+        if not connector.responds_to_event(event):
+            raise servo.EventHandlersNotFoundError(
+                f"no currently assembled connectors respond to the check event"
+            )
