@@ -5,10 +5,23 @@ import functools
 from inspect import isclass
 import pydantic
 import pydantic.fields
-from typing import Annotated, Any, Callable, Generator, Literal, Optional, Type, TypeVar, Union, cast, get_origin
+from typing import (
+    Annotated,
+    Any,
+    Callable,
+    Generator,
+    Literal,
+    Optional,
+    Type,
+    TypeVar,
+    Union,
+    cast,
+    get_origin,
+)
 
 from .core import BaseModel, HumanReadable, Numeric, Unit
 
+
 class Setting(BaseModel, abc.ABC):
     """Setting is an abstract base class for models that represent adjustable
     parameters of an application under optimization.
@@ -47,8 +60,9 @@ class Setting(BaseModel, abc.ABC):
             return new_setting
         except ValueError:
             import servo
+
             servo.logger.exception(f"Failed to parse safe_set value {repr(value)}")
-            if (vt := getattr(self, 'value_type', None)) is not None:
+            if (vt := getattr(self, "value_type", None)) is not None:
                 value = vt(value)
             return self.copy(update={"value": value})
 
@@ -56,7 +70,7 @@ class Setting(BaseModel, abc.ABC):
         return repr(self)
 
     @abc.abstractmethod
-    def __opsani_repr__(self) -> dict:
+    def __opsani_repr__(self) -> dict[str, Any]:
         """Return a representation of the setting serialized for use in Opsani
         API requests.
         """
@@ -111,10 +125,12 @@ class Setting(BaseModel, abc.ABC):
         validate_all = True
         validate_assignment = True
 
+
 # Helper methods for working with lists of settings
 def find_setting(settings: list[Setting], setting_name: str) -> Optional[Setting]:
     return next(iter(s for s in settings if s.name == setting_name), None)
 
+
 class EnumSetting(Setting):
     """EnumSetting objects describe a fixed set of values that can be applied to an
     adjustable parameter. Enum settings are not necessarily numeric and cover use-cases such as
@@ -143,7 +159,7 @@ class EnumSetting(Setting):
 
     @pydantic.root_validator(skip_on_failure=True)
     @classmethod
-    def _validate_value_in_values(cls, values: dict) -> dict[str, Any]:
+    def _validate_value_in_values(cls, values: dict[str, Any]) -> dict[str, Any]:
         value, options = values["value"], values["values"]
         if value is not None and value not in options:
             raise ValueError(
@@ -153,9 +169,11 @@ class EnumSetting(Setting):
         return values
 
     def summary(self) -> str:
-        return f"{self.__class__.__name__}(values={repr(self.values)}, unit={self.unit})"
+        return (
+            f"{self.__class__.__name__}(values={repr(self.values)}, unit={self.unit})"
+        )
 
-    def __opsani_repr__(self) -> dict:
+    def __opsani_repr__(self) -> dict[str, dict[Any, Any]]:
         return {
             self.name: self.dict(
                 include={"type", "unit", "values", "pinned", "value"}, exclude_none=True
@@ -203,7 +221,7 @@ class RangeSetting(Setting):
     @pydantic.root_validator(skip_on_failure=True)
     @classmethod
     def _attributes_must_be_of_same_type(cls, values: dict[str, Any]) -> dict[str, Any]:
-        range_types: dict[TypeVar[int, float], list[str]] = {}
+        range_types: dict[TypeVar, list[str]] = {}
         for attr in ("min", "max", "step"):
             value = values[attr] if attr in values else cls.__fields__[attr].default
             attr_cls = value.__class__
@@ -246,13 +264,17 @@ class RangeSetting(Setting):
 
         min_ = values["min"]
         if min_ > max_:
-            raise ValueError(f"min cannot be greater than max ({cls.human_readable(min_)} > {cls.human_readable(max_)})")
+            raise ValueError(
+                f"min cannot be greater than max ({cls.human_readable(min_)} > {cls.human_readable(max_)})"
+            )
 
         return max_
 
     @pydantic.root_validator(skip_on_failure=True)
     @classmethod
-    def _min_and_max_must_be_step_aligned(cls, values: dict[str, Any]) -> dict[str, Any]:
+    def _min_and_max_must_be_step_aligned(
+        cls, values: dict[str, Any]
+    ) -> dict[str, Any]:
         name, min_, max_, step = (
             values["name"],
             values["min"],
@@ -284,12 +306,21 @@ class RangeSetting(Setting):
                     if get_origin(value_type) is Union:
                         value_type = str
                     cast_diff, lower_min, upper_min, lower_max, upper_max = (
-                        value_type(v) for v in
-                        (diff, max_ - smaller_range, max_ - larger_range, min_ + smaller_range, min_ + larger_range)
+                        value_type(v)
+                        for v in (
+                            diff,
+                            max_ - smaller_range,
+                            max_ - larger_range,
+                            min_ + smaller_range,
+                            min_ + larger_range,
+                        )
                     )
                 except:
                     import servo
-                    servo.logger.exception(f"Failed to apply new formatting to derived RangeSetting validation")
+
+                    servo.logger.exception(
+                        f"Failed to apply new formatting to derived RangeSetting validation"
+                    )
                     raise ValueError(
                         f"{desc} min/max difference is not step aligned: {diff} is not a multiple of {step} (consider "
                         f"min {max_ - smaller_range} or {max_ - larger_range}, max {min_ + smaller_range} or {min_ + larger_range})."
@@ -306,16 +337,20 @@ class RangeSetting(Setting):
     def __str__(self) -> str:
         return f"{self.name} ({self.type} {self.human_readable(self.min)}-{self.human_readable(self.max)}, {self.human_readable(self.step)})"
 
-    def __opsani_repr__(self) -> dict:
+    def __opsani_repr__(self) -> dict[str, dict[Any, Any]]:
         return {
             self.name: self.dict(
                 include={"type", "unit", "min", "max", "step", "pinned", "value"},
-                exclude_none=True
+                exclude_none=True,
             )
         }
 
+
 def _is_step_aligned(value: Numeric, step: Numeric) -> bool:
-    return value == step or (decimal.Decimal(str(float(value))) % decimal.Decimal(str(float(step))) == 0)
+    return value == step or (
+        decimal.Decimal(str(float(value))) % decimal.Decimal(str(float(step))) == 0
+    )
+
 
 class CPU(RangeSetting):
     """CPU is a Setting that describes an adjustable range of values for CPU
@@ -332,7 +367,7 @@ class CPU(RangeSetting):
             return super().__init__(*args, **kwargs)
         return super().__init__(unit=Unit.cores, *args, **kwargs)
 
-    name = pydantic.Field(
+    name: str = pydantic.Field(
         "cpu", const=True, description="Identifies the setting as a CPU setting."
     )
     min: float = pydantic.Field(
@@ -366,7 +401,7 @@ class Memory(RangeSetting):
             return super().__init__(*args, **kwargs)
         return super().__init__(unit=Unit.gibibytes, *args, **kwargs)
 
-    name = pydantic.Field(
+    name: str = pydantic.Field(
         "mem", const=True, description="Identifies the setting as a Memory setting."
     )
 
@@ -389,7 +424,7 @@ class Replicas(RangeSetting):
     type derived thereof.
     """
 
-    name = pydantic.Field(
+    name: str = pydantic.Field(
         "replicas",
         const=True,
         description="Identifies the setting as a replicas setting.",
@@ -428,7 +463,7 @@ class InstanceType(EnumSetting):
     type derived thereof.
     """
 
-    name = pydantic.Field(
+    name: str = pydantic.Field(
         "inst_type",
         const=True,
         description="Identifies the setting as an instance type enum setting.",
@@ -438,14 +473,22 @@ class InstanceType(EnumSetting):
         description="The unit of instance types identifying the provider.",
     )
 
-def _suggest_step_aligned_values(value: Numeric, step: Numeric, *, in_repr: Optional[Callable[[Numeric], str]] = None) -> tuple[str, str]:
+
+def _suggest_step_aligned_values(
+    value: Numeric,
+    step: Numeric,
+    *,
+    in_repr: Optional[Callable[[Numeric], Union[str, float, int]]] = None,
+) -> tuple[str, str]:
     if in_repr is None:
         # return raw data for further processing
         in_repr = lambda x: x
 
     # declare numeric and textual representations
     parser = functools.partial(pydantic.parse_obj_as, value.__class__)
-    value_dec, step_dec = decimal.Decimal(str(float(value))), decimal.Decimal(str(float(step)))
+    value_dec, step_dec = decimal.Decimal(str(float(value))), decimal.Decimal(
+        str(float(step))
+    )
     lower_bound, upper_bound = value_dec, value_dec
     value_repr, lower_repr, upper_repr = in_repr(parser(value_dec)), None, None
 
@@ -495,66 +538,95 @@ def _suggest_step_aligned_values(value: Numeric, step: Numeric, *, in_repr: Opti
 
     return (lower_repr, upper_repr)
 
+
 class EnvironmentSetting(Setting):
     literal: Optional[str] = pydantic.Field(
-        None, description="(Optional) The environment variable name as used in the target system (this allows name to be "
-                         "set to a human readable string). Defaults to configured name when literal is not configured"
+        None,
+        description="(Optional) The environment variable name as used in the target system (this allows name to be "
+        "set to a human readable string). Defaults to configured name when literal is not configured",
     )
 
     @property
     def variable_name(self) -> str:
         return self.literal or self.name
 
-class NumericType(Type):
+
+class NumericType(Setting):
     @classmethod
     def __get_validators__(cls) -> Generator[Callable[..., Any], None, None]:
         yield cls.validate
 
     @classmethod
-    def validate(cls, value, field: pydantic.fields.ModelField):
+    def validate(cls, value, field: pydantic.fields.ModelField = None):
         if isclass(value) and issubclass(value, (int, float)):
             return value
 
-        if value == 'int':
+        if value == "int":
             return int
-        if value == 'float':
+        if value == "float":
             return float
 
         raise ValueError(f"Unrecognized numeric type {repr(value)}")
 
     @classmethod
     def __modify_schema__(cls, field_schema: dict[str, Any]):
-        field_schema.update(anyOf=['int', 'float'])
+        field_schema.update(anyOf=["int", "float"])
+
 
 class EnvironmentRangeSetting(RangeSetting, EnvironmentSetting):
-    # ENV Var values are almost always represented as a str, override value parsing to accomodate
-    value: Optional[Union[pydantic.StrictInt, float]] = pydantic.Field(
-        None, description="The optional value of the setting as reported by the servo"
-    )
-
     # # TODO promote to RangeSetting base
     value_type: NumericType = pydantic.Field(
         None, description="The optional data type of the value of the setting"
     )
 
+    # ENV Var values are almost always represented as a str, override value parsing to accomodate
+    value: Optional[Union[pydantic.StrictInt, float]] = pydantic.Field(
+        None, description="The optional value of the setting as reported by the servo"
+    )
+
     @pydantic.validator("value_type", pre=True)
     def _set_value_type_to_type(cls, value: Any) -> Union[Type[int], Type[float]]:
-        if value == 'int':
+        if value == "int":
             return int
-        if value == 'float':
+        if value == "float":
             return float
         return value
 
-    @pydantic.validator('value')
-    def _cast_value_to_value_type(cls, value: Any, values: dict) -> Optional[Union[pydantic.StrictInt, float]]:
-        if value is not None and (value_type := values.get('value_type')) is not None:
-            return value_type(value)
-        return value
+    @pydantic.root_validator
+    def _cast_value_to_value_type(cls, values: dict[Any, Any]) -> dict[Any, Any]:
+        if (value := values.get("value")) is not None and (
+            value_type := values.get("value_type")
+        ) is not None:
+            values["value"] = value_type(value)
+        return values
+
 
 class EnvironmentEnumSetting(EnumSetting, EnvironmentSetting):
     pass
 
-PydanticEnvironmentSettingAnnotation = Annotated[Union[EnvironmentRangeSetting, EnvironmentEnumSetting], pydantic.Field(discriminator='type')]
+
+# https://github.com/samuelcolvin/pydantic/issues/3714
+class EnvironmentSettingList(pydantic.BaseModel):
+    __root__: list[
+        Annotated[
+            Union[EnvironmentRangeSetting, EnvironmentEnumSetting],
+            pydantic.Field(discriminator="type"),
+        ]
+    ]
+
+    # above https://pydantic-docs.helpmanual.io/usage/models/#faux-immutability
+    def __iter__(self):
+        return iter(self.__root__)
+
+    def __getitem__(self, item):
+        return self.__root__[item]
+
+
+# TODO: revert to this annotation when the above is resolved
+# PydanticEnvironmentSettingAnnotation = Annotated[
+#     Union[EnvironmentRangeSetting, EnvironmentEnumSetting],
+#     pydantic.Field(discriminator="type"),
+# ]
 
 # TODO unused references to this stub in test (TestCommandConfiguration)
 # class CommandConfiguration(servo.BaseConfiguration):
