@@ -7,7 +7,17 @@ import contextlib
 import datetime
 import pathlib
 import time
-from typing import IO, Any, Awaitable, Callable, Dict, List, NamedTuple, Optional, TypeVar, Union, cast
+from typing import (
+    IO,
+    Any,
+    Awaitable,
+    Callable,
+    NamedTuple,
+    Optional,
+    TypeVar,
+    Union,
+    cast,
+)
 
 import loguru
 
@@ -23,7 +33,7 @@ __all__ = (
 )
 
 
-_DEFAULT_LIMIT = 2 ** 16  # 64 KiB
+_DEFAULT_LIMIT = 2**16  # 64 KiB
 
 
 # Type definition for streaming output callbacks.
@@ -45,15 +55,15 @@ class SubprocessResult(NamedTuple):
     """
 
     return_code: int
-    stdout: Optional[List[str]]
-    stderr: Optional[List[str]]
+    stdout: Optional[list[str]]
+    stderr: Optional[list[str]]
 
 
 async def stream_subprocess_exec(
     program: str,
     *args,
     cwd: Union[pathlib.Path, Callable[[], pathlib.Path]] = pathlib.Path.cwd,
-    env: Optional[Dict[str, str]] = None,
+    env: Optional[dict[str, str]] = None,
     timeout: Timeout = None,
     stdout_callback: Optional[OutputStreamCallback] = None,
     stderr_callback: Optional[OutputStreamCallback] = None,
@@ -104,7 +114,7 @@ async def run_subprocess_exec(
     program: str,
     *args,
     cwd: pathlib.Path = pathlib.Path.cwd(),
-    env: Optional[Dict[str, str]] = None,
+    env: Optional[dict[str, str]] = None,
     timeout: Timeout = None,
     stdin: Union[int, IO[Any], None] = None,
     stdout: Union[int, IO[Any], None] = asyncio.subprocess.PIPE,
@@ -133,8 +143,8 @@ async def run_subprocess_exec(
     :raises asyncio.TimeoutError: Raised if the timeout expires before the subprocess exits.
     :return: A named tuple value of the exit status and two string lists of standard output and standard error.
     """
-    stdout_list: List[str] = []
-    stderr_list: List[str] = []
+    stdout_list: list[str] = []
+    stderr_list: list[str] = []
     return SubprocessResult(
         await stream_subprocess_exec(
             program,
@@ -159,7 +169,7 @@ async def run_subprocess_shell(
     cmd: str,
     *,
     cwd: pathlib.Path = pathlib.Path.cwd(),
-    env: Optional[Dict[str, str]] = None,
+    env: Optional[dict[str, str]] = None,
     timeout: Timeout = None,
     stdin: Union[int, IO[Any], None] = None,
     stdout: Union[int, IO[Any], None] = asyncio.subprocess.PIPE,
@@ -187,8 +197,8 @@ async def run_subprocess_shell(
     :raises asyncio.TimeoutError: Raised if the timeout expires before the subprocess exits.
     :return: A named tuple value of the exit status and two string lists of standard output and standard error.
     """
-    stdout_list: List[str] = []
-    stderr_list: List[str] = []
+    stdout_list: list[str] = []
+    stderr_list: list[str] = []
     return SubprocessResult(
         await stream_subprocess_shell(
             cmd,
@@ -212,7 +222,7 @@ async def stream_subprocess_shell(
     cmd: str,
     *,
     cwd: Union[pathlib.Path, Callable[[], pathlib.Path]] = pathlib.Path.cwd,
-    env: Optional[Dict[str, str]] = None,
+    env: Optional[dict[str, str]] = None,
     timeout: Timeout = None,
     stdout_callback: Optional[OutputStreamCallback] = None,
     stderr_callback: Optional[OutputStreamCallback] = None,
@@ -263,15 +273,14 @@ async def stream_subprocess_shell(
     end = time.time()
     duration = Duration(end - start)
     if result == 0:
-        loguru.logger.success(
-            f"Subprocess succeeded in {duration} (`{cmd}`)"
-        )
+        loguru.logger.success(f"Subprocess succeeded in {duration} (`{cmd}`)")
     else:
         loguru.logger.error(
             f"Subprocess failed with return code {result} in {duration} (`{cmd}`)"
         )
     return result
 
+
 async def stream_subprocess_output(
     process: asyncio.subprocess.Process,
     *,
@@ -295,13 +304,15 @@ async def stream_subprocess_output(
     if process.stdout:
         tasks.append(
             asyncio.create_task(
-                _read_lines_from_output_stream(process.stdout, stdout_callback), name="stdout"
+                _read_lines_from_output_stream(process.stdout, stdout_callback),
+                name="stdout",
             )
         )
     if process.stderr:
         tasks.append(
             asyncio.create_task(
-                _read_lines_from_output_stream(process.stderr, stderr_callback), name="stderr"
+                _read_lines_from_output_stream(process.stderr, stderr_callback),
+                name="stderr",
             )
         )
 
@@ -310,10 +321,7 @@ async def stream_subprocess_output(
     )
     try:
         # Gather the stream output tasks and the parent process
-        gather_task = asyncio.gather(
-            *tasks,
-            process.wait()
-        )
+        gather_task = asyncio.gather(*tasks, process.wait())
         await asyncio.wait_for(gather_task, timeout=timeout_in_seconds)
 
     except (asyncio.TimeoutError, asyncio.CancelledError):
